==> beast-logger-3.0-20230909.091241-31-sources.jar: org/beast/logger/web/servlet/Slf4jTraceWebServletAutoConfiguration.java <==
package org.beast.logger.web.servlet;


import brave.Tracer;
import brave.Tracing;
import brave.http.HttpTracing;
import io.micrometer.tracing.brave.bridge.BraveTracer;
import jakarta.servlet.DispatcherType;
import org.springframework.boot.actuate.autoconfigure.tracing.BraveAutoConfiguration;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;


import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.Ordered;


@Configuration(proxyBeanMethods = false)
//@ConditionalOnBean(Tracing.class)
//@ConditionalOnClass({ Tracer.class, BraveTracer.class })
@ConditionalOnWebApplication(type = ConditionalOnWebApplication.Type.SERVLET)
@AutoConfigureAfter(BraveAutoConfiguration.class)
public class Slf4jTraceWebServletAutoConfiguration {

    @Bean
    public Slf4jTracingFilter slf4jTracingFilter(Tracing tracing) {
        return Slf4jTracingFilter.create(tracing);

    }

    @Bean
    public FilterRegistrationBean<Slf4jTracingFilter> slf4jTraceWebFilter(
            Slf4jTracingFilter tracingFilter
    ) {
        FilterRegistrationBean<Slf4jTracingFilter> filterRegistrationBean = new FilterRegistrationBean<>(
            tracingFilter
        );
        filterRegistrationBean.setDispatcherTypes(
                DispatcherType.ASYNC,
                DispatcherType.ERROR, DispatcherType.FORWARD, DispatcherType.INCLUDE,
                DispatcherType.REQUEST
        );
        filterRegistrationBean.setOrder(
                Ordered.HIGHEST_PRECEDENCE + 6
        );

        return filterRegistrationBean;
    }



}

==> beast-logger-3.0-20230909.091423-32-sources.jar: org/beast/logger/web/servlet/Slf4jTraceWebServletAutoConfiguration.java <==
package org.beast.logger.web.servlet;


import brave.Tracer;
import brave.Tracing;
import brave.http.HttpTracing;
import io.micrometer.tracing.brave.bridge.BraveTracer;
import jakarta.servlet.DispatcherType;
import org.springframework.boot.actuate.autoconfigure.tracing.BraveAutoConfiguration;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;


import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.Ordered;


@Configuration(proxyBeanMethods = false)
@ConditionalOnBean(Tracing.class)
//@ConditionalOnClass({ Tracer.class, BraveTracer.class })
@ConditionalOnWebApplication(type = ConditionalOnWebApplication.Type.SERVLET)
@AutoConfigureAfter(BraveAutoConfiguration.class)
public class Slf4jTraceWebServletAutoConfiguration {

    @Bean
    public Slf4jTracingFilter slf4jTracingFilter(Tracing tracing) {
        return Slf4jTracingFilter.create(tracing);

    }

    @Bean
    public FilterRegistrationBean<Slf4jTracingFilter> slf4jTraceWebFilter(
            Slf4jTracingFilter tracingFilter
    ) {
        FilterRegistrationBean<Slf4jTracingFilter> filterRegistrationBean = new FilterRegistrationBean<>(
            tracingFilter
        );
        filterRegistrationBean.setDispatcherTypes(
                DispatcherType.ASYNC,
                DispatcherType.ERROR, DispatcherType.FORWARD, DispatcherType.INCLUDE,
                DispatcherType.REQUEST
        );
        filterRegistrationBean.setOrder(
                Ordered.HIGHEST_PRECEDENCE + 6
        );

        return filterRegistrationBean;
    }



}
